@@ -10,7 +10,6 @@
 """
 import collections
 import json
-import logging
 import os
 import pickle
 import re
@@ -23,8 +22,7 @@ from typing import Any, Dict, Iterable, List, Sequence, Tuple, _GenericAlias, Un
 import numpy as np
 from pydantic import BaseModel
 from tqdm import tqdm
-
-logger = logging.getLogger(__name__)
+from loguru import logger
 
 
 # 创建一个目录
@@ -42,7 +40,7 @@ class PythonObjectEncoder(json.JSONEncoder):
         if isinstance(obj, set):
             return list(obj)
         if isinstance(obj, BaseModel):
-            return obj.dict(exclude_none=True, exclude_defaults=True)
+            return obj.model_dump(exclude_none=True, exclude_defaults=True)
         if isinstance(obj, datetime):
             return obj.strftime("%Y-%M-%d %H:%m:%S")
         if isinstance(obj, np.integer):
@@ -111,11 +109,6 @@ def jload(fp):
     return rs
 
 
-def split_surfix(filename: str) -> Tuple[str, str]:
-    name, ext = filename.rsplit(".", 1)
-    return name, ext
-
-
 # 将$s的内容load成一个json对象。
 def jloads(s: str):
     return json.loads(s, object_hook=as_python_object)
@@ -154,11 +147,11 @@ def jload_lines(fp, max_data_num=None, return_generator=False):
 # table类的文件转化为list of dict
 
 
-def table2json(path):
+def table2json(path, **kwargs):
     if path.endswith("csv"):
-        df = pd.read_csv(path)
+        df = pd.read_csv(path, **kwargs)
     if path.endswith("xlsx"):
-        df = pd.read_excel(path)
+        df = pd.read_excel(path, **kwargs)
     df.replace(np.nan, None, inplace=True)
     cols = df.columns.tolist()
     cols = [e for e in cols if not e.startswith("Unnamed")]
@@ -197,17 +190,17 @@ def load_lines(fp, return_generator=False):
 def read2list(file_path: Union[str, List], **kwargs) -> List[Union[str, dict]]:
 
     def _read2list(file_path, **kwargs):
-        surfix = os.path.splitext(file_path)[-1].lower()
-        if surfix == ".json":
+        suffix = os.path.splitext(file_path)[-1].lower()
+        if suffix == ".json":
             return jload(file_path, **kwargs)
-        if surfix == ".jsonl":
+        if suffix == ".jsonl":
             return jload_lines(file_path, **kwargs)
-        if surfix in [".xlsx", ".csv"]:
-            return table2json(file_path)
-        if surfix in [".txt"]:
+        if suffix in [".xlsx", ".csv"]:
+            return table2json(file_path, **kwargs)
+        if suffix in [".txt"]:
             return load_lines(file_path, **kwargs)
         else:
-            logger.warn(f"unkown surfix:{surfix}, read as txt")
+            logger.warn(f"unknown suffix:{suffix}, read as txt")
             return load_lines(file_path, **kwargs)
 
     if isinstance(file_path, list):
@@ -300,7 +293,7 @@ def flat(seq: Sequence[Iterable]) -> Iterable:
 
 # 将$seq序列聚合成dict。 key表示字典key生成的函数。 map_func表示字典value值的映射函数。
 # 返回的字典会根据value序列长度倒序排序
-def groupby(seq: Sequence, key=lambda x: x, map_func=lambda x: x,
+def groupby(seq: Sequence, key=lambda x: x, map_func=lambda x: x, reduce_func=None,
             sort_type="v_len", reverse=True) -> Dict[Any, List]:
     rs_dict = collections.defaultdict(list)
     for i in seq:
@@ -312,8 +305,9 @@ def groupby(seq: Sequence, key=lambda x: x, map_func=lambda x: x,
         if sort_type == "k":
             return x[0]
         return 0
-
     items = sorted(rs_dict.items(), key=sort_func, reverse=reverse)
+    if reduce_func:
+        items = [(k, reduce_func(v)) for k, v in items]
     return collections.OrderedDict(items)
 
 
@@ -334,8 +328,6 @@ def print_info(info, target_logger=None, fix_length=128):
         print(star_info)
 
 # 把一个dict转化到一个Union类型
-
-
 def union_parse_obj(union: _GenericAlias, d: dict):
     for cls in union.__args__:
         try:
@@ -346,8 +338,6 @@ def union_parse_obj(union: _GenericAlias, d: dict):
     raise Exception(f"fail to convert {d} to union {union}")
 
 # 获取一个包的最新version
-
-
 def get_latest_version(package_name: str) -> str:
     cmd = f"pip install {package_name}=="
     status, output = execute_cmd(cmd)
@@ -364,8 +354,6 @@ def get_latest_version(package_name: str) -> str:
         return latest_version
 
 # 获取一个version的下一个版本
-
-
 def get_next_version(version: str, level=0) -> str:
     pieces = version.split(".")
     idx = len(pieces) - level - 1
